@@ -37,6 +37,11 @@
  * All rights reserved.
  */
 
+/*
+ * Copyright (c) 2003-2006 Mahoroba Kobo / Bugest-Network
+ * All rights reserved.
+ */
+
 #ifndef _BGP_H
 #define _BGP_H
 
@@ -72,8 +77,12 @@
 #include "md5sig.h"
 #endif
 
-#define BV_VERSION	"0.38Beta"
-#define BV_COPYRIGHT	"Copyright (c) 1998-2002 Internet Initiative Japan Inc.\r\nCopyright (c) 2003-2005 Intec NetCore, Inc.\nBugest-Network"
+#ifdef IRRCHK
+#include "irrdif.h"
+#endif
+
+#define BV_VERSION	"0.40Beta"
+#define BV_COPYRIGHT	"Copyright (c) 1998-2002 Internet Initiative Japan Inc.\r\nCopyright (c) 2003-2005 Intec NetCore, Inc.\r\nCopyright (c) 2006-2007 Mahoroba Kobo. / Bugest-Network"
 
 /* BGP Header Type field defines */
 #define BGPTYPES                5
@@ -234,10 +243,13 @@
 #define IPv4_UNICAST		1
 #define IPv6_UNICAST		2
 
+#define AS_TRANS		(u_short)23456
+
 #define DEFSYSNAME		"BGPView"
 
 extern	net_ulong	IDENT;
-extern  u_short		LOCAL_AS;
+/* extern  u_short		LOCAL_AS; */
+extern  u_long		LOCAL_AS;
 extern	struct timeval	uptime;
 
 typedef struct {
@@ -248,10 +260,15 @@ typedef struct {
 typedef struct {
 	char		description[DESCSIZE];	/* Description */
 	boolean		peerstatus;		/* Peer Status (Shutdown) */
+	boolean		as4_enable;
+	boolean		as4_remote;
 	net_ulong	neighbor;		/* Neighbor Address */
-	u_short		remote_as;		/* REMOTE AS */
+	/* u_short		remote_as;		/* REMOTE AS */
+	u_long		remote_as;		/* Configured REMOTE AS */
+	u_long		remote_as4;		/* Received REMOTE 4Byte-AS */
 	net_ulong	local_id;		/* local IDENT */
-	u_short		local_as;		/* local AS */
+	/* u_short		local_as;		/* local AS */
+	u_long		local_as;		/* local AS */
 	char		admin_addr[FNAMESIZE];  /* Peer Admin Email */
 	char		nlri;			/* NLRI Type */
 	int		soc;			/* Socket Discripter */
@@ -279,6 +296,11 @@ typedef struct {
 						/* MD5 Password */
 #endif
 	int             session_re_init_timer;  /* Sec */
+#ifdef IRRCHK
+	boolean		irr_compare;		/* true:enable, false:disable */
+	char		irr_notify[FNAMESIZE];	/* Notify Email Address */
+	char		irr_notelevel;		/* Notification Level */
+#endif
 } PEERS;
 
 typedef struct {
