@@ -63,7 +63,8 @@ PEERS		peer[MAXPEERS];
 fd_set		readfds;
 int		sv_sock;
 net_ulong	IDENT;
-u_short		LOCAL_AS;
+/* u_short		LOCAL_AS; */
+u_long		LOCAL_AS;
 char		syslogname[FNAMESIZE];
 int		facility;
 char		configfile[FNAMESIZE];
@@ -216,6 +217,11 @@ int init()
 	/* save Start time */
 	gettimeofday(&uptime, (struct timezone *)0);
 
+#ifdef IRRCHK
+	/* IRR Check Initializing */
+	init_irrif();
+#endif
+
 	read_conf(configfile);
 	pr_log(VLOG_GLOB, LOG_ALL, "Initializing Process\n", ON);
 
@@ -235,13 +241,13 @@ int init()
 
 	/* lookup network number */
 	if ((hp = gethostbyname(hostname)) == NULL) {
-		sprintf(strbuf, "%s: host unkown.\n", hostname);
+		sprintf(strbuf, "%s: host unknown.\n", hostname);
 		pr_log(VLOG_GLOB, LOG_ALL, strbuf, ON);
-		return 1;
+		/* return 1; */
 	}
 #ifdef DEBUG
 	printf("My Hostname : %s\n", hostname);
-	printf("GET hostname: %s\n", hp->h_name);
+	if (hp != NULL) printf("GET hostname: %s\n", hp->h_name);
 #endif
 
 	/* get socket */
@@ -326,6 +332,7 @@ int init()
 
 	/* Cron read conf */
 	read_cron_file();
+
 	printf("BGPView cron Started\n");
 
 	printf("BGPView Initialize Done..\n");
@@ -443,6 +450,10 @@ int pn;
 	sprintf(logstr, "  Error Code    = %d (%s)\n", (int)code, note[code]);
 	pr_log(VLOG_NOTI, pn, logstr, OFF);
 
+#ifdef DEBUG
+	printf("DEBUG: NOTIFICATION Message:\n");
+	printf("DEBUG:  Error Code    = %d (%s)\n", (int)code, note[code]);
+#endif
 	idx = *(peer[pn].data + 1);
 	switch(code) {
 	case 1:
@@ -460,11 +471,21 @@ int pn;
 	sprintf(logstr, "  Error Subcode = %d (%s)\n", (int)idx, submsg);
 	pr_log(VLOG_NOTI, pn, logstr, OFF);
 	pr_log(VLOG_NOTI, pn, "  Data:\n", OFF);
+#ifdef DEBUG
+	printf("DEBUG:  Error Subcode = %d (%s)\n", (int)idx, submsg);
+	printf("DEBUG:  Data:\n");
+#endif
 	for(ptr = 2;ptr < peer[pn].datalen; ptr++){
 		sprintf(logstr, "%02X",*(peer[pn].data + ptr));
 		pr_log(VLOG_NOTI, pn, logstr, OFF);
+#ifdef DEBUG
+		printf("%s", logstr);
+#endif
 	}
 	pr_log(VLOG_NOTI, pn, "\n", OFF);
+#ifdef DEBUG
+	printf("\n", logstr);
+#endif
 }
 
 int sockwrite(soc, buf, len)
@@ -539,7 +560,13 @@ int sendopen(int pn)
 	/* store_int16(buf+16, 29); */
 	*(buf+18) = BGP_OPEN;
 	*(buf+19) = 4;
-	store_int16(buf+20, peer[pn].local_as);
+	if (peer[pn].local_as > 65535) {
+		/* Non-Mappable Local AS */
+		store_int16(buf+20, AS_TRANS);
+	} else {
+		/* Mappable locla AS */
+		store_int16(buf+20, (u_short)peer[pn].local_as);
+	}
 	store_int16(buf+22, peer[pn].holdtimer);
 	store_int32(buf+24, ntohl(peer[pn].local_id));
 	*(buf+28) = '\0';
@@ -551,7 +578,7 @@ int sendopen(int pn)
 		*(buf+bt+30) = 6;
 		*(buf+bt+31) = CAP_MPBGP;
 		*(buf+bt+32) = 4;
-		store_int16(buf+33, AF_IPV6);
+		store_int16(buf+bt+33, AF_IPV6);
 		*(buf+bt+35) = 0;
 		*(buf+bt+36) = SAFI_NLRI_UNI;
 		bt += 8;
@@ -560,12 +587,22 @@ int sendopen(int pn)
 		*(buf+bt+30) = 6;
 		*(buf+bt+31) = CAP_MPBGP;
 		*(buf+bt+32) = 4;
-		store_int16(buf+33, AF_IPV4);
+		store_int16(buf+bt+33, AF_IPV4);
 		*(buf+bt+35) = 0;
 		*(buf+bt+36) = SAFI_NLRI_UNI;
 		bt += 8;
 	}
 
+	/*** 4 Octet Capability Enabling ***/
+	if (peer[pn].as4_enable) {
+		*(buf+bt+29) = BGPOPT_CAPABILITY;
+		*(buf+bt+30) = 6;
+		*(buf+bt+31) = CAP_4OCTAS;
+		*(buf+bt+32) = 4;
+		store_int32(buf+bt+33, peer[pn].local_as);
+		bt += 8;
+	}
+
 	*(buf+28) = bt;
 	store_int16(buf+16, 29+bt);
 
@@ -723,6 +760,8 @@ int recvdata(int pn,int len)
                         pr_log2(VLOG_GLOB, pn, ON,
                                 "Socket Read Error pn=%d DataLen=%d\n",
                                 pn, len);
+			rcnt++;
+			if (rcnt >= 6) break;
                         continue;
                 }
 		memcpy(((char *)peer[pn].data + readed), readbuf, ret);
@@ -766,6 +805,9 @@ int check_header(int pn)
 		if (ret == 0) {
 			/* Connection Closed */
 			peer[pn].event = BGP_STOP;
+#ifdef DEBUG
+			printf("DEBUG: Header Error\n");
+#endif
 			return 0;
 		}
 
@@ -818,7 +860,7 @@ int check_header(int pn)
 	if (bgp_head.length > HEADERLENGTH) {
 #ifdef DEBUG
 		pr_log2(VLOG_GLOB, pn, ON,
-			"Receive Data Size = %d / Peer = %d\n",
+			"DEBUG: Receive Data Size = %d / Peer = %d\n",
 			(bgp_head.length - HEADERLENGTH), pn);
 #endif
 		ret = recvdata(pn, (bgp_head.length - HEADERLENGTH));
@@ -1074,7 +1116,14 @@ main(int argc, char *argv[])
 				timer_value.tv_sec  = 0;
 				timer_value.tv_usec = 0;
 			}
-				
+#ifdef IRRCHK
+			if (irr_check_enable == 1) {
+			  if (irr_walker_check() == IRRCHK_ACTIVE) {
+				timer_value.tv_sec  = 0;
+				timer_value.tv_usec = 0;
+			  }
+			}
+#endif	
 			resetfds();
 			nfd = select(FD_SETSIZE, &readfds, 
 						NULL, NULL, &timer_value);
@@ -1214,10 +1263,13 @@ main(int argc, char *argv[])
 						pr_log(VLOG_GLOB, LOG_ALL,
 						  "  Disabled Peer\n", OFF);
 						close(ns);
+					/***** Templary Comment Out 
+						2006/08/26 By K.Kondo
 					} else if (peer[pn].resume == ON) {
 						pr_log(VLOG_GLOB, LOG_ALL,
 						  "  Now Resuming Peer\n", OFF);
 						close(ns);
+					*************************************/
 					} else if (peer[pn].soc != ns) {
 					  if (peer[pn].status <= ACTIVE) {
 					    /* Server Socket Connect */
@@ -1308,6 +1360,11 @@ main(int argc, char *argv[])
 #endif
 		/* BVS Client Socket Check */
 		bvs_input(&readfds);
+
+#ifdef IRRCHK
+		/* IRR Check */
+		walk_bgp_chk_irr();
+#endif
 	}
 
 	close(sv_sock);
