@@ -328,6 +328,7 @@ int bvc_bgpsum(BVS_CMD_PARAM *prm)
 	char		prline[128];
 	struct in_addr	adr;
 	char		localident[20];
+	char		tempstr[20];
 
 
 	clno = (prm->noparam).clno;
@@ -349,15 +350,16 @@ int bvc_bgpsum(BVS_CMD_PARAM *prm)
 		adr.s_addr = peer[pn].local_id;
 		strcpy(localident, inet_ntoa(adr));
 		adr.s_addr = peer[pn].neighbor;
+		strcpy(tempstr, ulongtofourbyteas(peer[pn].local_as));
 		if (peer[pn].peerstatus == true) {
-			sprintf(prline, "%2d %-15s %-5d %-15s %-5d %-12s\r\n",
-				pn, localident, peer[pn].local_as,
-				inet_ntoa(adr), peer[pn].remote_as,
+			sprintf(prline, "%2d %-15s %-11s %-15s %-11s %-12s\r\n",
+				pn, localident, tempstr,
+				inet_ntoa(adr), ulongtofourbyteas(peer[pn].remote_as),
 				fsm_state_names[peer[pn].status]);
 		} else {
-			sprintf(prline, "%2d %-15s %-5d %-15s %-5d Admin Down\r\n",
-				pn, localident, peer[pn].local_as,
-				inet_ntoa(adr), peer[pn].remote_as);
+			sprintf(prline, "%2d %-15s %-11s %-15s %-11s Admin Down\r\n",
+				pn, localident, tempstr,
+				inet_ntoa(adr), ulongtofourbyteas(peer[pn].remote_as));
 		}
 		bvs_write(clno, prline);
 	}
@@ -443,15 +445,15 @@ int bvc_shoneighbor(BVS_CMD_PARAM *prm)
 		sprintf(prline, "    Neighbor Address : %s\r\n",
 					inet_ntoa(sin));
 		bvs_write(clno, prline);
-		sprintf(prline, "    Remote AS        : %d\r\n",
-					peer[pn].remote_as);
+		sprintf(prline, "    Remote AS        : %s\r\n",
+					ulongtofourbyteas(peer[pn].remote_as));
 		bvs_write(clno, prline);
 		sin.s_addr = peer[pn].local_id;
 		sprintf(prline, "    Individual IDENT : %s\r\n",
 					inet_ntoa(sin));
 		bvs_write(clno, prline);
-		sprintf(prline, "    Individual AS    : %d\r\n",
-					peer[pn].local_as);
+		sprintf(prline, "    Individual AS    : %s\r\n",
+					ulongtofourbyteas(peer[pn].local_as));
 		bvs_write(clno, prline);
 		if (peer[pn].peerstatus == false) {
 			bvs_write(clno, 
@@ -696,8 +698,8 @@ int bvc_shoversion(BVS_CMD_PARAM *prm)
 {
 	int		clno;
 	struct in_addr	sin;
-	char		prline[1024];
-	char		bufline[1024];
+	char		prline[2048];
+	char		bufline[2048];
 	int		cnt;
 	struct timeval	curtime;
 	long		timediff;
@@ -724,7 +726,8 @@ int bvc_shoversion(BVS_CMD_PARAM *prm)
 	sin.s_addr = IDENT;
 	sprintf(prline, "  Local BGP Identifier    : %s\r\n", inet_ntoa(sin));
 	bvs_write(clno, prline);
-	sprintf(prline, "  Local AS Number         : %d\r\n", LOCAL_AS);
+	sprintf(prline, "  Local AS Number         : %d\r\n", 
+						ulongtofourbyteas(LOCAL_AS));
 	bvs_write(clno, prline);
 	sprintf(prline, "  Sendmail Command        : %s\r\n", sendmail_command);
 	bvs_write(clno, prline);
