@@ -185,6 +185,16 @@ void bvs_init_set_default()
 	bvc_clear_route_history_v6((BVS_CMD_PARAM *)0);
 #endif
 
+#ifdef IRRCHK
+	bvc_show_irr_status((BVS_CMD_PARAM *)0);
+	bvc_do_output_irr_status((BVS_CMD_PARAM *)0);
+	bvc_show_irr_status_summary((BVS_CMD_PARAM *)0);
+#endif
+
+	bvc_output_aslist_nei((BVS_CMD_PARAM *)0);
+
+
+
 	/* Entry Commands */
 	bvs_entry_command(bvs_cmd_exit, "quit", "Logout BGPView Shell", false);
 	bvs_entry_command(bvs_clearbgp, "clear ip bgp %ADR", 
@@ -420,8 +430,51 @@ void bvs_init_set_default()
 #endif /* RADIX */
 	bvs_entry_command(bvc_dotimertest, "do timer test",
 					"DEBUG: Common Timer Test", false);
+#endif /* DEBUG */
+
+#ifdef IRRCHK
+	bvs_entry_command(bvc_show_irr_status, "show irr status",
+			"Show IRR route check", true);
+	bvs_entry_command(bvc_show_irr_status_active, "show irr status active",
+			"Show IRR route check", true);
+	/*
+	bvs_entry_command(bvc_show_irr_status_nei, 
+			"show irr status active neighbor %ADR",
+			"Show IRR route check for a neighbor", true);
+	bvs_entry_command(bvc_show_irr_status_active_nei, 
+			"show irr status active neighbor %ADR active",
+			"Show IRR route check for a neighbor", true);
+	*/
+	
+	bvs_entry_command(bvc_do_output_irr_status, 
+			"do output irrstats filename %STR all",
+			"Output IRR Status to File", true);
+	bvs_entry_command(bvc_do_output_irr_status_active, 
+			"do output irrstats filename %STR active",
+			"Output IRR Status to File", true);
+	/*
+	bvs_entry_command(bvc_do_output_irr_status_nei, 
+			"do output irrstats filename %STR neighbor %ADR all",
+			"Output IRR Status to File for a neighbor", true);
+	bvs_entry_command(bvc_do_output_irr_status_active_nei, 
+			"do output irrstats filename %STR neighbor %ADR active",
+			"Output IRR Status to File for a neighbor", true);
+	*/
+
+	bvs_entry_command(bvc_show_irr_status_summary,
+			"show irr status summary",
+			"Show IRR Statys Summary", true);
+	/*
+	bvs_entry_command(bvc_show_irr_status_summary_nei,
+			"show irr status summary neighbor %ADR",
+			"Show IRR Statys Summary for a neighbor", true);
+	*/
 #endif
 
+	bvs_entry_command(bvc_output_aslist_nei, 
+			"do output aslist filename %STR neighbor %ADR",
+			"Output AS-List to File for a neighbor", true);
+	
 #ifdef DEBUG
 	/* View Entried Command */
 	{
@@ -540,12 +593,12 @@ int bvs_init_start()
 	if ((hp = gethostbyname(hostname)) == NULL) {
 		sprintf(strbuf, "%s: host unknown.\n", hostname);
 		pr_log(VLOG_GLOB, LOG_ALL, strbuf, ON);
-		return(1);
+		/* return(1); */
 	}
 
 #ifdef DEBUG
 	printf("DEBUG: BVS Hostname : %s\n", hostname);
-	printf("DEBUG: GET Hostname : %s\n", hp->h_name);
+	if (hp != NULL) printf("DEBUG: GET Hostname : %s\n", hp->h_name);
 #endif
 
 #ifdef DEBUG
@@ -918,6 +971,9 @@ int bvs_exec_command(int clno)
 			prm.noparam.clno = clno;
 			/* Retcode is continue code */
 			ret = (*function)(&prm);
+#ifdef DEBUG
+			printf("DEBUG: Command Exec Return Code = %d\n", ret);
+#endif
 			(bvs_clients+clno)->enable_more = false;
 			switch(ret) {
 			case 0:
