@@ -121,7 +121,8 @@ char *fname;
 #endif
 		if (strcmp("LOCAL_AS", cmd) == 0) {
 			if (val == NULL) continue;
-			sscanf(val, "%hu", &LOCAL_AS);
+			/* sscanf(val, "%hu", &LOCAL_AS); */
+			LOCAL_AS = fourbyteastoulong(val);
 		} else if (strcmp("IDENTIFIER", cmd) == 0) {
 			if (val == NULL) continue;
 			inet_aton(val, &pin);
@@ -147,6 +148,17 @@ char *fname;
 			if (val == NULL) continue;
 			sscanf(val, "%ld", &rthistcleartime_v6.tv_sec);
 			rthistcleartime_v6.tv_usec = 0;
+#endif
+#ifdef IRRCHK
+		} else if (strcmp("IRR_CHECK", cmd) == 0) {
+			if (val == NULL) continue;
+			set_irrparam(SET_IRR_DISABLE, val);
+		} else if (strcmp("IRR_HOST", cmd) == 0) {
+			if (val == NULL) continue;
+			set_irrparam(SET_IRR_HOST, val);
+		} else if (strcmp("IRR_PORT", cmd) == 0) {
+			if (val == NULL) continue;
+			set_irrparam(SET_IRR_PORT, val);
 #endif
 		} else if (strcmp("CRON", cmd) == 0) {
 			if (val == NULL) continue;
@@ -215,9 +227,12 @@ char *fname;
 			}
 			bzero(&peer[pn], sizeof(PEERS));
 			peer[pn].peerstatus= true;
+			peer[pn].as4_enable= false;
+			peer[pn].as4_remote= false;
 			peer[pn].data	   = NULL;
 			peer[pn].neighbor  = 0;
 			peer[pn].remote_as = 0;
+			peer[pn].remote_as4= 0;
 			peer[pn].datalen   = 0;
 			peer[pn].soc       = -1;
 			peer[pn].flag	   = 0;
@@ -247,20 +262,27 @@ char *fname;
 		} else if (strcmp("PEER_ADMIN", cmd) == 0) {
 			if (val == NULL) continue;
 			strncpy(peer[pn].admin_addr, val, FNAMESIZE-1);
+		} else if (strcmp("4OCTETS_AS", cmd) == 0) {
+			if (val == NULL) continue;
+			if (strcmp("ON", val) == 0) {
+				peer[pn].as4_enable = true;
+			}
 		} else if (strcmp("ADDRESS", cmd) == 0) {
 			if (val == NULL) continue;
 			inet_aton(val, &pin);
 			peer[pn].neighbor = pin.s_addr;
 		} else if (strcmp("REMOTE_AS", cmd) == 0) {
 			if (val == NULL) continue;
-			sscanf(val, "%hu", &peer[pn].remote_as);
+			/* sscanf(val, "%hu", &peer[pn].remote_as); */
+			peer[pn].remote_as = fourbyteastoulong(val);
 		} else if (strcmp("IND_IDENT", cmd) == 0) {
 			if (val == NULL) continue;
 			inet_aton(val, &pin);
 			peer[pn].local_id = pin.s_addr;
 		} else if (strcmp("IND_AS", cmd) == 0) {
 			if (val == NULL) continue;
-			sscanf(val, "%hu", &peer[pn].local_as);
+			peer[pn].local_as = fourbyteastoulong(val);
+			/* sscanf(val, "%hu", &peer[pn].local_as); */
 		} else if (strcmp("HOLD_TIMER", cmd) == 0) {
 			if (val == NULL) continue;
 			sscanf(val, "%d", &cnt);
@@ -361,6 +383,20 @@ char *fname;
 			if (val == NULL) continue;
 			sscanf(val, "%d", &peer[pn].session_re_init_timer);
 		}
+#ifdef IRRCHK
+		else if (strcmp("IRRCOMPARE", cmd) == 0) {
+			if (val == NULL) continue;
+			set_irr_peerparam(SET_P_IRRCOMPARE, val, pn);
+		}
+		else if (strcmp("IRRNOTIFY", cmd) == 0) {
+			if (val == NULL) continue;
+			set_irr_peerparam(SET_P_IRRNOTIFY, val, pn);
+		}
+		else if (strcmp("IRRNOTELEVEL", cmd) == 0) {
+			if (val == NULL) continue;
+			set_irr_peerparam(SET_P_IRRNOTELEVEL, val, pn);
+		}
+#endif /* IRRCHK */
 	}
 	fclose(fp);
 	if (pn == -1) {
