@@ -162,6 +162,27 @@ char capability_check(char *param, char length, int pn)
 			/* This Capability is Ignored */
 			break;
 
+		case CAP_4OCTAS: /* 4Octet AS Capability */
+			pr_log(VLOG_GLOB, pn, 
+				"CAPACHK: Receive 4Byte AS Capability\n", ON);
+			peer[pn].remote_as4 = buf2ulong(ptr+2);
+			pr_log(VLOG_GLOB, pn, 
+				"CAPACHK: Remote 4Byte AS Num = %ld\n",
+				peer[pn].remote_as4);
+#ifdef DEBUG
+			printf("DEBUG: Received 4Byte AS Number = %ld\n", 
+							peer[pn].remote_as4);
+#endif
+			if (peer[pn].as4_enable) {
+				/* AS Check */
+				if (peer[pn].remote_as != peer[pn].remote_as4) {
+					opterr = BAD_PEER_AS;
+				} else {
+					peer[pn].as4_remote = true;
+				}
+			}
+			break;
+
 		case 128: /* Capability Private Use 128 */
 			pr_log(VLOG_GLOB, pn,
 			  "CAPACHK: Private Capability Code(Cisco?) is Ignored\n", ON);
@@ -197,6 +218,7 @@ int openerrchk(int pn)
 	char	paramlen;
 	char	*paramval;
 	char	opterr;
+	u_short	as2;
 
 	ptr = peer[pn].data;
 	/* Version Check */
@@ -209,7 +231,12 @@ int openerrchk(int pn)
 	ptr++;
 
 	/* Autonomous Number Check */
-	if (buf2ushort(ptr) != peer[pn].remote_as) {
+	if (peer[pn].remote_as > 65535) {
+		as2 = AS_TRANS;
+	} else {
+		as2 = peer[pn].remote_as;
+	}
+	if (buf2ushort(ptr) != as2) {
 		pr_log(VLOG_GLOB, pn, "OPENCHK: Bad AS Number\n",ON);
 		return BAD_PEER_AS;
 	}
