@@ -85,7 +85,7 @@ int entry_route(RADIX_T *node, ROUTE_INFO *rinfo)
 	ROUTE_INFO	*pathbuf;
 #endif
 
-#ifdef DEBUG
+#ifdef RADIXDEBUG
 	printf("DEBUG: RADIX: Entry Route : %08X/%d\n",
 			ntohl(rinfo->prefix), rinfo->length);
 #endif
@@ -130,6 +130,12 @@ int entry_route(RADIX_T *node, ROUTE_INFO *rinfo)
 				free(pathbuf->pathset_ptr);
 				pathbuf->pathset_ptr = NULL;
 			}
+#ifdef IRRCHK
+			if ((rlist->route_data)->irr != NULL) {
+				free((rlist->route_data)->irr);
+				(rlist->route_data)->irr = NULL;
+			}
+#endif
 			free(rlist->route_data);
 			rlist->route_data = ribuf;
 #ifdef RTHISTORY
@@ -199,7 +205,7 @@ int add_route(ROUTE_INFO *rinfo)
 			}
 			loopbit++;
 		}
-#ifdef DEBUG
+#ifdef RADIXDEBUG
 		printf("DEBUG: RADIX: Add Route / Node Check Parm\n");
 		printf("DEBUG: RADIX:  rinfo->length = %d / c_leaf->check_bit = %d\n",
 						rinfo->length, c_leaf->check_bit);
@@ -209,7 +215,7 @@ int add_route(ROUTE_INFO *rinfo)
 		
 		if (!(cbit <= loopbit) || (loopbit != c_leaf->check_bit)) { 
 			/* add node */
-#ifdef DEBUG
+#ifdef RADIXDEBUG
 			printf("DEBUG: RADIX: ADD node\n");
 #endif
 			ladd = (RADIX_T *)malloc(sizeof(RADIX_T));
@@ -320,7 +326,7 @@ int withdraw_route(int pn, net_ulong prefix, int masklen)
 	    rcode = 1; /* no route */
 	    break;
 	  }
-#ifdef DEBUG
+#ifdef RADIXDEBUG
 	  printf("DEBUG: RADIX: DELETE: Checking pref=%08X / mask=%d",
 					ntohl(node->key), node->masklen);
 	  printf(" / Check_bit=%d\n", node->check_bit);
@@ -340,7 +346,7 @@ int withdraw_route(int pn, net_ulong prefix, int masklen)
 	    while(rlist != NULL) {
 	      if (pn == check_id1topn(rlist->route_data->source)) {
 	      /* delete route */
-#ifdef DEBUG
+#ifdef RADIXDEBUG
 	        printf("DEBUG: RADIX: DELETE: pref = %08X / Mask = %d",
 	  	  ntohl(rlist->route_data->prefix), rlist->route_data->length);
 	        printf(" / Neighbor = %08X\n", ntohl(rlist->route_data->source));
@@ -370,6 +376,12 @@ int withdraw_route(int pn, net_ulong prefix, int masklen)
 		      free(pathbuf->pathset_ptr);
 		      pathbuf->pathset_ptr = NULL;
 		    }
+#ifdef IRRCHK
+		    if ((rlist->route_data)->irr != NULL) {
+		      free((rlist->route_data)->irr);
+		      (rlist->route_data)->irr = NULL;
+		    }
+#endif
 		    free(rlist->route_data);
 		    if (brlist == NULL) {
 		      node->rinfo = rlist->next;
@@ -388,6 +400,12 @@ int withdraw_route(int pn, net_ulong prefix, int masklen)
 		    free(pathbuf->pathset_ptr);
 		    pathbuf->pathset_ptr = NULL;
 		  }
+#ifdef IRRCHK
+		  if ((rlist->route_data)->irr != NULL) {
+		    free((rlist->route_data)->irr);
+		    (rlist->route_data)->irr = NULL;
+		  }
+#endif
 		  free(rlist->route_data);
 		  if (brlist == NULL) {
 		    node->rinfo = rlist->next;
@@ -437,14 +455,14 @@ int withdraw_route(int pn, net_ulong prefix, int masklen)
 		      node->l_leaf->upleaf = node;
 		    }
 		  }
-#ifdef DEBUG
+#ifdef RADIXDEBUG
 		  errno = 0;
 	          printf("DEBUG: RADIX: WITHDRAW: Freeing Node = %08X/%d CB=%d\n",
 			ntohl(bnode->key), bnode->masklen, bnode->check_bit);
 #endif
 		  free(bnode);
 		  nodes--;
-#ifdef DEBUG
+#ifdef RADIXDEBUG
 		  if (errno != 0) perror("DEBUG: RADIX: FreeError: ");
 #endif
 		  if (node->upleaf == NULL) break;
@@ -477,17 +495,17 @@ RADIX_T *show_route_all(RADIX_T *curnode, int *upcode)
 		/* Show route from TOP Node */
 		bnode = radix_top;
 		*upcode = 0;
-#ifdef DEBUG
+#ifdef RADIXDEBUG
 		printf("DEBUG: RADIX: Goto Most Left Leaf\n");
 #endif
 		while(bnode->l_leaf != NULL) {
 			bnode = bnode->l_leaf;
-#ifdef DEBUG
+#ifdef RADIXDEBUG
 			printf("DEBUG: RADIX:   Move to Node = %08X\n",bnode);
 #endif
 		}
 		if (bnode->rinfo != NULL) {
-#ifdef DEBUG
+#ifdef RADIXDEBUG
 			printf("DEBUG: RADIX:   Found First Route Data\n");
 #endif
 			return(bnode);
@@ -497,13 +515,13 @@ RADIX_T *show_route_all(RADIX_T *curnode, int *upcode)
 		bnode = curnode;
 	}
 
-#ifdef DEBUG
+#ifdef RADIXDEBUG
 	printf("DEBUG: RADIX: Start Tree Pointer = %08X\n", curnode);
 #endif
 
 	rcode = 0;
 	while(1) {
-#ifdef DEBUG
+#ifdef RADIXDEBUG
 		printf("DEBUG: RADIX: ALLROUTE: Checkbit = %d / upcode=%d\n",
 						bnode->check_bit,*upcode);
 #endif
@@ -557,7 +575,7 @@ u_long delete_peer_route(RADIX_T **cnode, int pn)
 	while(rlist != NULL) {
 		if (pn == check_id1topn(rlist->route_data->source)) {
 			/* delete route */
-#ifdef DEBUG
+#ifdef RADIXDEBUG
 	printf("DEBUG: RADIX: DELETE: pref = %08X / Mask = %d\n",
 		ntohl(rlist->route_data->prefix), rlist->route_data->length);
 	printf("                      Neighbor = %08X\n",
@@ -568,6 +586,12 @@ u_long delete_peer_route(RADIX_T **cnode, int pn)
 				free(pathbuf->pathset_ptr);
 				pathbuf->pathset_ptr = NULL;
 			}
+#ifdef IRRCHK
+			if ((rlist->route_data)->irr != NULL) {
+				free((rlist->route_data)->irr);
+				(rlist->route_data)->irr = NULL;
+			}
+#endif
 			free(rlist->route_data);
 			if (brlist == NULL) {
 				node->rinfo = rlist->next;
@@ -613,14 +637,14 @@ u_long delete_peer_route(RADIX_T **cnode, int pn)
 						node->l_leaf->upleaf = node;
 					}
 				}
-#ifdef DEBUG
+#ifdef RADIXDEBUG
 				errno = 0;
 	printf("DEBUG: RADIX: WITHDRAW: Freeing Node = %08X/%d CB=%d\n",
 			ntohl(bnode->key), bnode->masklen, bnode->check_bit);
 #endif
 				free(bnode);
 				nodes--;
-#ifdef DEBUG
+#ifdef RADIXDEBUG
 	if (errno != 0) perror("DEBUG: RADIX: FreeError: ");
 #endif
 				if (node->upleaf == NULL) break;
