@@ -237,13 +237,15 @@ void pr_update(int pn)
 	int		attr_len, plen, ret;
 	u_int		attr_octs, type_code;
 	ROUTE_INFO	getroute, prroute;
+	ROUTE_INFO	as4_getroute;
 	char		logstr[128];
 	prefix_t	outpre;
-	char		pathbuf[4096];
-	int		pathbuflen;
+	char		pathbuf[4096], as4_pathbuf[4096];
+	int		pathbuflen, as4_pathbuflen;
 	int		ipv6updcnt, ipv6wdrcnt;
 	V6ROUTE_BUF	v6update, v6withdraw;
 	ROUTE_INFO_V6	v6getroute, v6prroute;
+	ROUTE_INFO_V6	as4_v6getroute;
 	V6ROUTE_LIST	*listbuf;
 
 	static char	*path_attr[] = {
@@ -469,7 +471,6 @@ void pr_update(int pn)
 				ATRFL_SET(SET_PATHTYPE, getroute.attribute_flag);
 				ATRFL_SET(SET_PATHTYPE, v6getroute.attribute_flag);
 				ptmp = 0;
-				/* getroute.path_set[0] = '\0'; */
 				pathbuf[0] = '\0';
 				while(ptmp < attr_octs) {
 				  strcpy(logstr, "    PATH Segment Type = ");
@@ -502,31 +503,39 @@ void pr_update(int pn)
 				  switch(getroute.path_type) {
 				    case AS_CONFED_SET:
 				    case AS_CONFED_SEQUENCE:
-					/* strcat(getroute.path_set, "("); */
 					strcat(pathbuf, "(");
 					break;
 				  }
 				  cp = ptr + ptmp;
-				  for(cnt = 0; cnt < length; cnt++, cp += 2){
+				  if (peer[pn].as4_remote && peer[pn].as4_enable) {
+				    for(cnt = 0; cnt < length; cnt++, cp += 4){
+				      strcpy(cbuf, 
+					ulongtofourbyteas(buf2ulong(cp)));
+				      strcat(cbuf, " ");
+				      strcat(pathbuf, cbuf);
+				    }
+				  } else {
+				    for(cnt = 0; cnt < length; cnt++, cp += 2){
 					sprintf(cbuf, "%d ",
 						(int)buf2ushort(cp));
-					/* strcat(getroute.path_set, cbuf); */
 					strcat(pathbuf, cbuf);
+				    }
 				  }
 				  switch(getroute.path_type) {
 				    case AS_CONFED_SET:
 				    case AS_CONFED_SEQUENCE:
-					/* cnt = strlen(getroute.path_set); */
 					cnt = strlen(pathbuf);
 					if (cnt > 0) {
-					  /* getroute.path_set[cnt-1] = '\0'; */
 					  pathbuf[cnt-1] = '\0';
 					}
-					/* strcat(getroute.path_set, ") "); */
 					strcat(pathbuf, ") ");
 					break;
 				  }
-				  ptmp += length*2;
+				  if (peer[pn].as4_remote && peer[pn].as4_enable) {
+				    ptmp += length*4;
+				  } else {
+				    ptmp += length*2;
+				  }
 				}
 				
 				/* Add 16 Sep 2001 Dynamic Path set */
@@ -539,10 +548,6 @@ void pr_update(int pn)
 					v6getroute.pathset_ptr = &pathbuf[0];
 					strcpy(getroute.pathset_ptr, pathbuf);
 					strcpy(v6getroute.pathset_ptr, pathbuf);
-					/*
-					sprintf(logstr, "    AS_Path = %s\n",
-								getroute.path_set);
-					*/
 					sprintf(logstr, "    AS_Path = %s\n",
 								getroute.pathset_ptr);
 				}
@@ -701,9 +706,90 @@ void pr_update(int pn)
 				ptr += attr_octs;
 				break;
 
-			case ATTR_EXTENDED_COMMUNITIES: /* Rosen */
 			case ATTR_NEW_AS_PATH: /* E.Chen */
+				if (attr_octs == 0) {
+					pr_log(VLOG_UPAT, pn, 
+					"    NEW_AS_PATH Not Presented\n", OFF);
+					break;
+				}
+				/*******************
+				ATRFL_SET(SET_PATHTYPE, as4_getroute.attribute_flag);
+				ATRFL_SET(SET_PATHTYPE, as4_v6getroute.attribute_flag);
+				********************/
+				ptmp = 0;
+				as4_pathbuf[0] = '\0';
+				while(ptmp < attr_octs) {
+				  strcpy(logstr, "    AS4_PATH Segment Type = ");
+				  as4_getroute.path_type = *(ptr+ptmp);
+				  as4_v6getroute.path_type = *(ptr+ptmp);
+				  ptmp++;
+				  switch(as4_getroute.path_type){
+			  	  case AS_SET:
+				  	strcat(logstr, "AS_SET : ");
+					break;
+				  case AS_SEQUENCE:
+					strcat(logstr, "AS_SEQUENCE : ");
+					break;
+				  case AS_CONFED_SET:
+					strcat(logstr, "AS_CONFED_SET : ");
+					break;
+				  case AS_CONFED_SEQUENCE:
+					strcat(logstr, "AS_CONFED_SEQUENCE : ");
+					break;
+				  default:
+					sprintf(cbuf, "ABNORMAL(%d) : ",
+							as4_getroute.path_type);
+					strcat(logstr, cbuf);
+				  }
+				  pr_log(VLOG_UPAT, pn, logstr, OFF);
+				  length = *(ptr+ptmp);
+				  ptmp++;
+				  sprintf(logstr, "%d\n", length);
+				  pr_log(VLOG_UPAT, pn, logstr, OFF);
+				  switch(as4_getroute.path_type) {
+				    case AS_CONFED_SET:
+				    case AS_CONFED_SEQUENCE:
+					strcat(as4_pathbuf, "(");
+					break;
+				  }
+				  cp = ptr + ptmp;
+				  for(cnt = 0; cnt < length; cnt++, cp += 4){
+					sprintf(cbuf, "%d.%d ",
+						(int)buf2ushort(cp),
+						(int)buf2ushort(cp+2));
+					strcat(as4_pathbuf, cbuf);
+				  }
+				  switch(as4_getroute.path_type) {
+				    case AS_CONFED_SET:
+				    case AS_CONFED_SEQUENCE:
+					cnt = strlen(as4_pathbuf);
+					if (cnt > 0) {
+					  as4_pathbuf[cnt-1] = '\0';
+					}
+					strcat(as4_pathbuf, ") ");
+					break;
+				  }
+				  ptmp += length*4;
+				}
+				
+				/* Add 16 Sep 2001 Dynamic Path set */
+				if (strlen(as4_pathbuf) == 0) {
+					as4_getroute.pathset_ptr = NULL;
+					as4_v6getroute.pathset_ptr = NULL;
+					sprintf(logstr, "    AS_Path = N/A\n");
+				} else {
+					as4_getroute.pathset_ptr = &as4_pathbuf[0];
+					as4_v6getroute.pathset_ptr = &as4_pathbuf[0];
+					strcpy(as4_getroute.pathset_ptr, as4_pathbuf);
+					strcpy(as4_v6getroute.pathset_ptr, as4_pathbuf);
+					sprintf(logstr, "    AS4_Path = %s\n",
+					   	     as4_getroute.pathset_ptr);
+				}
+				pr_log(VLOG_UPAT, pn, logstr, OFF);
+				ptr += attr_octs;
+				break;
 			case ATTR_NEW_AGGREGATOR: /* E.Chen */
+			case ATTR_EXTENDED_COMMUNITIES: /* Rosen */
 
 			default:
 				/* Unknown Attribute Error */
